# The Schema-Guided Dialogue Dataset

Originally from the
[Google Research
Datasets](https://github.com/google-research-datasets/dstc8-schema-guided-dialogue/blob/main/README.md).
See that page for details.
